@@ -1,5 +1,5 @@
 name = "csinscapp"
-version = "0.1.4"
+version = "0.1.5"
 
 CLICK = 0
 MOUSE_DOWN = 1  
@@ -318,6 +318,18 @@ class Label (Control):
     else:    
       self.widget.style["display"] = "flex;" if self._visible == True else "none;"  
 
+class TextBox (Control):
+  def __init__(self, single_line = True, text = "", x = 0, y = 0, width = 64, height = 32):
+    self.widget = gui.TextInput(single_line = single_line, width = width, height = height)  
+    super(TextBox, self).__init__(x, y, width, height)
+  @property
+  def data(self):
+    return self.widget.get_value()
+  @data.setter
+  def data(self, value):
+    self.widget.set_value(value)
+  
+
 class Button (Control):
   def __init__(self, text = "", x = 0, y = 0, width = 64, height = 32):
     self.widget = gui.Button(text, width = width, height = height)  
